import type { CountryCode, ShippingPriceData, StateCode } from '@uppfirst/geo-shipping-prices/types/Shipping';
import type { Decimal } from 'decimal.js';
export interface ReservePricing {
    base: number;
    traitCost: number;
    taxCost: number;
    shippingCost: number;
    total: number;
    gainedCredit: number;
}
interface ClaimPricing {
    base: number;
    total: number;
    gainedCredit: number;
}
type AggregatePricing = ClaimPricing;
export interface Pricing {
    items: {
        startAmountPercent: number;
        reserve: ReservePricing & {
            taxPercent: number;
        };
        claim: ClaimPricing;
        aggregate: AggregatePricing;
    }[];
    summary: {
        reserve: ReservePricing;
        claim: ClaimPricing;
        aggregate: AggregatePricing & {
            usedCredit: number;
        };
    };
}
export interface Currency {
    code: string;
    symbol: string;
    decimals: number;
}
export interface BaseProduct {
    price: number | Decimal;
    startAmountPercent: number | Decimal;
    rewardShare: number | Decimal;
    currency: {
        decimals: number | Decimal;
        symbol: string;
    };
    shipping?: ShippingPriceData;
}
export interface TraitCombination {
    price: number | Decimal;
}
export interface CalculateArgs {
    items: {
        product: BaseProduct;
        combination?: TraitCombination;
        quantity: number;
    }[];
    usedCreditReserve?: number | Decimal;
    usedCreditClaim?: number | Decimal;
    countryCode?: CountryCode;
    stateCode?: StateCode;
}
/**
 * Options for the calculate function.
 */
export interface CalculateOpts {
    returnSmallestUnit?: boolean;
}
export {};
